==> v1.7.0.3.tar.gz: bypass-paywalls-firefox-clean/sites.js <==
var defaultSites =
{
  "Adweek": "adweek.com",
  "Aftonbladet": "aftonbladet.se",
  "Algemeen Dagblad": "ad.nl",
  "American Affairs": "americanaffairsjournal.org",
  "American Banker": "americanbanker.com",
  "Baltimore Sun": "baltimoresun.com",
  "Barron's": "barrons.com",
  "Bendigo Advertiser": "bendigoadvertiser.com.au",
  "Bloomberg": "bloomberg.com",
  "Bloomberg Quint (free articles only)": "bloombergquint.com",
  "Business Insider": "businessinsider.com",
  "Cairns Post": "cairnspost.com.au",
  "Caixin Global": "caixinglobal.com",
  "Central Western Daily": "centralwesterndaily.com.au",
  "Challenges": "challenges.fr",
  "Chemical & Engineering News": "cen.acs.org",
  "Chicago Tribune": "chicagotribune.com",
  "Clarín": "clarin.com",
  "CommonWealth Magazine Taiwan": "cw.com.tw",
  "Corriere Della Sera": "corriere.it",
  "Crain's Chicago Business": "chicagobusiness.com",
  "Dagblad van het Noorden": "dvhn.nl",
  "Dagens Nyheter": "dn.se",
  "Daily Liberal": "dailyliberal.com.au",
  "Daily Press": "dailypress.com",
  "Dark Reading": "darkreading.com",
  "De Tijd": "tijd.be",
  "DeMorgen": "demorgen.be",
  "Digiday": "digiday.com",
  "El Comercio": "elcomercio.pe",
  "El Mercurio": "elmercurio.com",
  "El País": "elpais.com",
  "Encyclopedia Britannica": "britannica.com",
  "Eureka Report": "eurekareport.com.au",
  "Exame": "exame.abril.com.br",
  "Financial News": "fnlondon.com",
  "Financial Times": "ft.com",
  "First Things": "firstthings.com",
  "Folha de S. Paulo": "folha.uol.com.br",
  "Foreign Policy": "foreignpolicy.com",
  "Fortune": "fortune.com",
  "Gestión": "gestion.pe",
  "Glassdoor": "glassdoor.com",
  "Gold Coast Bulletin": "goldcoastbulletin.com.au",
  "Groene Amsterdammer": "groene.nl",
  "Haaretz English": "haaretz.com",
  "Haaretz": "haaretz.co.il",
  "Handelsblatt": "handelsblatt.com",
  "Harper's Magazine": "harpers.org",
  "Hartford Courant": "courant.com",
  "Harvard Business Review": "hbr.org",
  "Harvard Business Review Taiwan": "hbrtaiwan.com",
  "Herald Sun": "heraldsun.com.au",
  "Het Financieel Dagblad": "fd.nl",
  "Humo.be": "humo.be",
  "Inc.com": "inc.com",
  "Il Messaggero": "ilmessaggero.it",
  "Illawarra Mercury": "illawarramercury.com.au",
  "Intelligent Investor": "intelligentinvestor.com.au",
  "Kleine Zeitung": "kleinezeitung.at",
  "L'Écho": "lecho.be",
  "L'Opinion": "lopinion.fr",
  "La Dépêche": "ladepeche.fr",
  "La Nación": "lanacion.com.ar",
  "La Repubblica": "repubblica.it",
  "La Stampa": "lastampa.it",
  "La Tercera": "latercera.com",
  "Le Devoir": "ledevoir.com",
  "Le Journal du Dimanche": "lejdd.fr",
  "Le Monde": "lemonde.fr",
  "Le Parisien": "leparisien.fr",
  "Le Scienze": "lescienze.it",
  "Leeuwarder Courant": "lc.nl",
  "Les Échos (free articles only)": "lesechos.fr",
  "Libération (free articles only)": "liberation.fr",
  "LiveMint": "livemint.com",
  "Loeb Classical Library": "loebclassics.com",
  "London Review of Books": "lrb.co.uk",
  "Los Angeles Business Journal": "labusinessjournal.com",
  "Los Angeles Times": "latimes.com",
  "Medium (all sites)": "medium.com",
  "Mexico News Daily": "mexiconewsdaily.com",
  "Miami Herald": "miamiherald.com",
  "MIT Sloan Management Review": "sloanreview.mit.edu",
  "MIT Technology Review": "technologyreview.com",
  "Modern Healthcare": "modernhealthcare.com",
  "Mountain View Voice": "mv-voice.com",
  "National Post": "nationalpost.com",
  "National Review": "nationalreview.com",
  "Neue Zürcher Zeitung": "nzz.ch",
  "New York Magazine": "nymag.com",
  "New Zealand Herald": "nzherald.co.nz",
  "Newcastle Herald": "newcastleherald.com.au",
  "Nikkei Asian Review": "asia.nikkei.com",
  "Northern Territory News": "ntnews.com.au",
  "NRC Handelsblad": "nrc.nl",
  "O Estado de S. Paulo": "estadao.com.br",
  "O Globo": "globo.com",
  "Orange County Register": "ocregister.com",
  "Orlando Sentinel": "orlandosentinel.com",
  "Palo Alto Online": "paloaltoonline.com",
  "Parool": "parool.nl",
  "Philosophy Now": "philosophynow.org",
  "Pittsburgh Post Gazette": "post-gazette.com",
  "Quartz": "qz.com",
  "Quora": "quora.com",
  "San Diego Union Tribune": "sandiegouniontribune.com",
  "San Francisco Chronicle": "sfchronicle.com",
  "Science & Vie": "science-et-vie.com",
  "Scientific American (free articles only)": "scientificamerican.com",
  "Scribd (documents only)": "scribd.com",
  "Seeking Alpha": "seekingalpha.com",
  "SOFREP": "sofrep.com",
  "Statista": "statista.com",
  "SunSentinel": "sun-sentinel.com",
  "Switzer Report": "switzersuperreport.com.au",
  "Tech in Asia": "techinasia.com",
  "Telegraaf": "telegraaf.nl",
  "The Advertiser": "adelaidenow.com.au",
  "The Advocate": "theadvocate.com.au",
  "The Age": "theage.com.au",
  "The American Interest": "the-american-interest.com",
  "The Athletic": "theathletic.com",
  "The Athletic UK": "theathletic.co.uk",
  "The Atlantic": "theatlantic.com",
  "The Australian Financial Review": "afr.com",
  "The Australian": "theaustralian.com.au",
  "The Border Mail": "bordermail.com.au",
  "The Boston Globe": "bostonglobe.com",
  "The Business Journals": "bizjournals.com",
  "The Canberra Times": "canberratimes.com.au",
  "The Christian Science Monitor": "csmonitor.com",
  "The Courier": "thecourier.com.au",
  "The Courier-Mail": "couriermail.com.au",
  "The Daily Advertiser": "dailyadvertiser.com.au",
  "The Daily Beast (free articles only)": "thedailybeast.com",
  "The Daily Telegraph": "dailytelegraph.com.au",
  "The Denver Post": "denverpost.com",
  "The Diplomat": "thediplomat.com",
  "The Economist": "economist.com",
  "The Examiner": "examiner.com.au",
  "The Globe and Mail": "theglobeandmail.com",
  "The Hindu": "thehindu.com",
  "The Irish Times (free articles only)": "irishtimes.com",
  "The Japan Times": "japantimes.co.jp",
  "The Marker": "themarker.com",
  "The Mercury News": "mercurynews.com",
  "The Mercury Tasmania": "themercury.com.au",
  "The Morning Call": "mcall.com",
  "The Nation": "thenation.com",
  "The New Republic": "newrepublic.com",
  "The New Statesman": "newstatesman.com",
  "The New York Times": "nytimes.com",
  "The New Yorker": "newyorker.com",
  "The News-Gazette": "news-gazette.com",
  "The Northern Daily Leader": "northerndailyleader.com.au",
  "The Philadelphia Inquirer": "inquirer.com",
  "The Port Macquarie News": "portnews.com.au",
  "The Sacramento Bee (free articles only)": "sacbee.com",
  "The Saturday Paper": "thesaturdaypaper.com.au",
  "The Seattle Times": "seattletimes.com",
  "The Spectator": "spectator.co.uk",
  "The Spectator Australia": "spectator.com.au",
  "The Standard": "standard.net.au",
  "The Sydney Morning Herald": "smh.com.au",
  "The Telegraph": "telegraph.co.uk",
  "The Times": "thetimes.co.uk",
  "The Times Literary Supplement": "the-tls.co.uk",
  "The Toronto Star": "thestar.com",
  "The Wall Street Journal": "wsj.com",
  "The Washington Post": "washingtonpost.com",
  "The Weekly Times": "weeklytimesnow.com.au",
  "Towards Data Science": "towardsdatascience.com",
  "Townsville Bulletin": "townsvillebulletin.com.au",
  "Trouw": "trouw.nl",
  "Valeurs Actuelles": "valeursactuelles.com",
  "Vanity Fair": "vanityfair.com",
  "Volkskrant": "volkskrant.nl",
  "Vrij Nederland": "vn.nl",
  "WAtoday": "watoday.com.au",
  "Winston-Salem Journal": "journalnow.com",
  "Wired": "wired.com",
  "World Politics Review": "worldpoliticsreview.com",
  "——— Block Paywall-scripts ———": "###",
  "Outbrain": "outbrain.com",
  "Poool.fr": "poool.fr",
  "TinyPass": "tinypass.com",
  "Piano.io": "piano.io"
}

==> v1.7.1.0.tar.gz: bypass-paywalls-firefox-clean/sites.js <==
var defaultSites =
{
  "Adweek": "adweek.com",
  "Aftonbladet": "aftonbladet.se",
  "Algemeen Dagblad": "ad.nl",
  "American Affairs": "americanaffairsjournal.org",
  "American Banker": "americanbanker.com",
  "Baltimore Sun": "baltimoresun.com",
  "Barron's": "barrons.com",
  "Bendigo Advertiser": "bendigoadvertiser.com.au",
  "Bloomberg": "bloomberg.com",
  "Bloomberg Quint (free articles only)": "bloombergquint.com",
  "Business Insider": "businessinsider.com",
  "Cairns Post": "cairnspost.com.au",
  "Caixin Global": "caixinglobal.com",
  "Central Western Daily": "centralwesterndaily.com.au",
  "Challenges": "challenges.fr",
  "Chemical & Engineering News": "cen.acs.org",
  "Chicago Tribune": "chicagotribune.com",
  "Clarín": "clarin.com",
  "CommonWealth Magazine Taiwan": "cw.com.tw",
  "Corriere Della Sera": "corriere.it",
  "Crain's Chicago Business": "chicagobusiness.com",
  "Dagblad van het Noorden": "dvhn.nl",
  "Dagens Nyheter": "dn.se",
  "Daily Liberal": "dailyliberal.com.au",
  "Daily Press": "dailypress.com",
  "Dark Reading": "darkreading.com",
  "De Tijd": "tijd.be",
  "DeMorgen": "demorgen.be",
  "Digiday": "digiday.com",
  "El Comercio": "elcomercio.pe",
  "El Mercurio": "elmercurio.com",
  "El País": "elpais.com",
  "Encyclopedia Britannica": "britannica.com",
  "Eureka Report": "eurekareport.com.au",
  "Exame": "exame.abril.com.br",
  "Financial News": "fnlondon.com",
  "Financial Times": "ft.com",
  "First Things": "firstthings.com",
  "Folha de S. Paulo": "folha.uol.com.br",
  "Foreign Policy": "foreignpolicy.com",
  "Fortune": "fortune.com",
  "Frankfurter Allgemeine Zeitung": "faz.net",
  "Gestión": "gestion.pe",
  "Glassdoor": "glassdoor.com",
  "Gold Coast Bulletin": "goldcoastbulletin.com.au",
  "Groene Amsterdammer": "groene.nl",
  "Haaretz English": "haaretz.com",
  "Haaretz": "haaretz.co.il",
  "Handelsblatt": "handelsblatt.com",
  "Harper's Magazine": "harpers.org",
  "Hartford Courant": "courant.com",
  "Harvard Business Review": "hbr.org",
  "Harvard Business Review Taiwan": "hbrtaiwan.com",
  "Herald Sun": "heraldsun.com.au",
  "Het Financieel Dagblad": "fd.nl",
  "Humo.be": "humo.be",
  "Inc.com": "inc.com",
  "Il Messaggero": "ilmessaggero.it",
  "Illawarra Mercury": "illawarramercury.com.au",
  "Intelligent Investor": "intelligentinvestor.com.au",
  "Kleine Zeitung": "kleinezeitung.at",
  "L'Écho": "lecho.be",
  "L'Opinion": "lopinion.fr",
  "La Dépêche": "ladepeche.fr",
  "La Nación": "lanacion.com.ar",
  "La Repubblica": "repubblica.it",
  "La Stampa": "lastampa.it",
  "La Tercera": "latercera.com",
  "Le Devoir": "ledevoir.com",
  "Le Journal du Dimanche": "lejdd.fr",
  "Le Journal du Net": "journaldunet.com",
  "Le Parisien": "leparisien.fr",
  "Le Scienze": "lescienze.it",
  "Leeuwarder Courant": "lc.nl",
  "Les Échos": "lesechos.fr",
  "Libération (free articles only)": "liberation.fr",
  "LiveMint": "livemint.com",
  "Loeb Classical Library": "loebclassics.com",
  "London Review of Books": "lrb.co.uk",
  "Los Angeles Business Journal": "labusinessjournal.com",
  "Los Angeles Times": "latimes.com",
  "Medium (all sites)": "medium.com",
  "Mexico News Daily": "mexiconewsdaily.com",
  "Miami Herald": "miamiherald.com",
  "MIT Sloan Management Review": "sloanreview.mit.edu",
  "MIT Technology Review": "technologyreview.com",
  "Modern Healthcare": "modernhealthcare.com",
  "Mountain View Voice": "mv-voice.com",
  "National Post": "nationalpost.com",
  "National Review": "nationalreview.com",
  "Neue Zürcher Zeitung": "nzz.ch",
  "New York Magazine": "nymag.com",
  "New Zealand Herald": "nzherald.co.nz",
  "Newcastle Herald": "newcastleherald.com.au",
  "Nikkei Asian Review": "asia.nikkei.com",
  "Northern Territory News": "ntnews.com.au",
  "NRC Handelsblad": "nrc.nl",
  "O Estado de S. Paulo": "estadao.com.br",
  "O Globo": "globo.com",
  "Orange County Register": "ocregister.com",
  "Orlando Sentinel": "orlandosentinel.com",
  "Palo Alto Online": "paloaltoonline.com",
  "Parool": "parool.nl",
  "Philosophy Now": "philosophynow.org",
  "Pittsburgh Post Gazette": "post-gazette.com",
  "Quartz": "qz.com",
  "Quora": "quora.com",
  "San Diego Union Tribune": "sandiegouniontribune.com",
  "San Francisco Chronicle": "sfchronicle.com",
  "Science & Vie": "science-et-vie.com",
  "Sciences et Avenir": "sciencesetavenir.fr",
  "Scientific American (free articles only)": "scientificamerican.com",
  "Scribd (documents only)": "scribd.com",
  "Seeking Alpha": "seekingalpha.com",
  "SOFREP": "sofrep.com",
  "Statista": "statista.com",
  "SunSentinel": "sun-sentinel.com",
  "Switzer Report": "switzersuperreport.com.au",
  "Tech in Asia": "techinasia.com",
  "Telegraaf": "telegraaf.nl",
  "The Advertiser": "adelaidenow.com.au",
  "The Advocate": "theadvocate.com.au",
  "The Age": "theage.com.au",
  "The American Interest": "the-american-interest.com",
  "The Athletic": "theathletic.com",
  "The Athletic UK": "theathletic.co.uk",
  "The Atlantic": "theatlantic.com",
  "The Australian Financial Review": "afr.com",
  "The Australian": "theaustralian.com.au",
  "The Border Mail": "bordermail.com.au",
  "The Boston Globe": "bostonglobe.com",
  "The Business Journals": "bizjournals.com",
  "The Canberra Times": "canberratimes.com.au",
  "The Christian Science Monitor": "csmonitor.com",
  "The Courier": "thecourier.com.au",
  "The Courier-Mail": "couriermail.com.au",
  "The Daily Advertiser": "dailyadvertiser.com.au",
  "The Daily Beast (free articles only)": "thedailybeast.com",
  "The Daily Telegraph": "dailytelegraph.com.au",
  "The Denver Post": "denverpost.com",
  "The Diplomat": "thediplomat.com",
  "The Economist": "economist.com",
  "The Examiner": "examiner.com.au",
  "The Globe and Mail": "theglobeandmail.com",
  "The Hindu": "thehindu.com",
  "The Irish Times (free articles only)": "irishtimes.com",
  "The Japan Times": "japantimes.co.jp",
  "The Marker": "themarker.com",
  "The Mercury News": "mercurynews.com",
  "The Mercury Tasmania": "themercury.com.au",
  "The Morning Call": "mcall.com",
  "The Nation": "thenation.com",
  "The New Republic": "newrepublic.com",
  "The New Statesman": "newstatesman.com",
  "The New York Times": "nytimes.com",
  "The New Yorker": "newyorker.com",
  "The News-Gazette": "news-gazette.com",
  "The Northern Daily Leader": "northerndailyleader.com.au",
  "The Philadelphia Inquirer": "inquirer.com",
  "The Port Macquarie News": "portnews.com.au",
  "The Sacramento Bee (free articles only)": "sacbee.com",
  "The Saturday Paper": "thesaturdaypaper.com.au",
  "The Seattle Times": "seattletimes.com",
  "The Spectator": "spectator.co.uk",
  "The Spectator Australia": "spectator.com.au",
  "The Standard": "standard.net.au",
  "The Sydney Morning Herald": "smh.com.au",
  "The Telegraph": "telegraph.co.uk",
  "The Times": "thetimes.co.uk",
  "The Times Literary Supplement": "the-tls.co.uk",
  "The Toronto Star": "thestar.com",
  "The Wall Street Journal": "wsj.com",
  "The Washington Post": "washingtonpost.com",
  "The Weekly Times": "weeklytimesnow.com.au",
  "Towards Data Science": "towardsdatascience.com",
  "Townsville Bulletin": "townsvillebulletin.com.au",
  "Trouw": "trouw.nl",
  "Valeurs Actuelles": "valeursactuelles.com",
  "Vanity Fair": "vanityfair.com",
  "Volkskrant": "volkskrant.nl",
  "Vrij Nederland": "vn.nl",
  "WAtoday": "watoday.com.au",
  "Winston-Salem Journal": "journalnow.com",
  "Wired": "wired.com",
  "World Politics Review": "worldpoliticsreview.com",
  "——— Block Paywall-scripts ———": "###",
  "Outbrain": "outbrain.com",
  "Poool.fr": "poool.fr",
  "TinyPass": "tinypass.com",
  "Piano.io": "piano.io"
}
